==> idyntree-5.1.0.tar.gz: idyntree-5.1.0/src/model/src/FreeFloatingMatrices.cpp <==
/*
 * Copyright (C) 2015 Fondazione Istituto Italiano di Tecnologia
 *
 * Licensed under either the GNU Lesser General Public License v3.0 :
 * https://www.gnu.org/licenses/lgpl-3.0.html
 * or the GNU Lesser General Public License v2.1 :
 * https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
 * at your option.
 */


#include <iDynTree/Model/FreeFloatingMatrices.h>
#include <iDynTree/Model/Model.h>

#include <cassert>

namespace iDynTree
{

FrameFreeFloatingJacobian::FrameFreeFloatingJacobian(size_t nrOfDofs): MatrixDynSize(6,6+nrOfDofs)
{
    MatrixDynSize::zero();
}


FrameFreeFloatingJacobian::FrameFreeFloatingJacobian(const Model& model)
{
    MatrixDynSize::resize(6,6+model.getNrOfDOFs());
    MatrixDynSize::zero();
}

bool FrameFreeFloatingJacobian::isConsistent(const Model& model) const
{
    return (MatrixDynSize::rows() == 6 &&
            MatrixDynSize::cols() == 6+model.getNrOfDOFs());
}

void FrameFreeFloatingJacobian::resize(const Model& model)
{
    MatrixDynSize::resize(6,6+model.getNrOfDOFs());
}

FrameFreeFloatingJacobian::~FrameFreeFloatingJacobian()
{

}

MomentumFreeFloatingJacobian::MomentumFreeFloatingJacobian(size_t nrOfDofs): MatrixDynSize(6,6+nrOfDofs)
{
    MatrixDynSize::zero();
}


MomentumFreeFloatingJacobian::MomentumFreeFloatingJacobian(const Model& model)
{
    MatrixDynSize::resize(6,6+model.getNrOfDOFs());
    MatrixDynSize::zero();
}

bool MomentumFreeFloatingJacobian::isConsistent(const Model& model) const
{
    return (MatrixDynSize::rows() == 6 &&
            MatrixDynSize::cols() == 6+model.getNrOfDOFs());
}

void MomentumFreeFloatingJacobian::resize(const Model& model)
{
    MatrixDynSize::resize(6,6+model.getNrOfDOFs());
}

MomentumFreeFloatingJacobian::~MomentumFreeFloatingJacobian()
{

}

FreeFloatingMassMatrix::FreeFloatingMassMatrix(size_t nrOfDofs): MatrixDynSize(6+nrOfDofs,6+nrOfDofs)
{
    MatrixDynSize::zero();
}


FreeFloatingMassMatrix::FreeFloatingMassMatrix(const Model& model)
{
    MatrixDynSize::resize(6+model.getNrOfDOFs(),6+model.getNrOfDOFs());
    MatrixDynSize::zero();
}

void FreeFloatingMassMatrix::resize(const Model& model)
{
    MatrixDynSize::resize(6+model.getNrOfDOFs(),6+model.getNrOfDOFs());
}

FreeFloatingMassMatrix::~FreeFloatingMassMatrix()
{

}

}

==> idyntree-14.0.1.tar.gz: idyntree-14.0.1/src/model/src/FreeFloatingMatrices.cpp <==
// SPDX-FileCopyrightText: Fondazione Istituto Italiano di Tecnologia (IIT)
// SPDX-License-Identifier: BSD-3-Clause


#include <iDynTree/FreeFloatingMatrices.h>
#include <iDynTree/Model.h>

#include <cassert>

namespace iDynTree
{

FrameFreeFloatingJacobian::FrameFreeFloatingJacobian(size_t nrOfDofs): MatrixDynSize(6,6+nrOfDofs)
{
    MatrixDynSize::zero();
}


FrameFreeFloatingJacobian::FrameFreeFloatingJacobian(const Model& model)
{
    MatrixDynSize::resize(6,6+model.getNrOfDOFs());
    MatrixDynSize::zero();
}

bool FrameFreeFloatingJacobian::isConsistent(const Model& model) const
{
    return (MatrixDynSize::rows() == 6 &&
            MatrixDynSize::cols() == 6+model.getNrOfDOFs());
}

void FrameFreeFloatingJacobian::resize(const Model& model)
{
    MatrixDynSize::resize(6,6+model.getNrOfDOFs());
}

FrameFreeFloatingJacobian::~FrameFreeFloatingJacobian()
{

}

MomentumFreeFloatingJacobian::MomentumFreeFloatingJacobian(size_t nrOfDofs): MatrixDynSize(6,6+nrOfDofs)
{
    MatrixDynSize::zero();
}


MomentumFreeFloatingJacobian::MomentumFreeFloatingJacobian(const Model& model)
{
    MatrixDynSize::resize(6,6+model.getNrOfDOFs());
    MatrixDynSize::zero();
}

bool MomentumFreeFloatingJacobian::isConsistent(const Model& model) const
{
    return (MatrixDynSize::rows() == 6 &&
            MatrixDynSize::cols() == 6+model.getNrOfDOFs());
}

void MomentumFreeFloatingJacobian::resize(const Model& model)
{
    MatrixDynSize::resize(6,6+model.getNrOfDOFs());
}

MomentumFreeFloatingJacobian::~MomentumFreeFloatingJacobian()
{

}

FreeFloatingMassMatrix::FreeFloatingMassMatrix(size_t nrOfDofs): MatrixDynSize(6+nrOfDofs,6+nrOfDofs)
{
    MatrixDynSize::zero();
}


FreeFloatingMassMatrix::FreeFloatingMassMatrix(const Model& model)
{
    MatrixDynSize::resize(6+model.getNrOfDOFs(),6+model.getNrOfDOFs());
    MatrixDynSize::zero();
}

void FreeFloatingMassMatrix::resize(const Model& model)
{
    MatrixDynSize::resize(6+model.getNrOfDOFs(),6+model.getNrOfDOFs());
}

FreeFloatingMassMatrix::~FreeFloatingMassMatrix()
{

}

}
